@@ -46,13 +46,24 @@ else:
 
 
 def getMetarObs(response):
+    """
+    Processes a DataAccessLayer "obs" response into a dictionary,
+    with special consideration for multi-value parameters
+    "presWeather", "skyCover", and "skyLayerBase".
+
+    Args:
+            response: DAL getGeometry() list
+
+    Returns:
+            A dictionary of METAR obs
+    """
     from datetime import datetime
     single_val_params = ["timeObs", "stationName", "longitude", "latitude",
                          "temperature", "dewpoint", "windDir",
                          "windSpeed", "seaLevelPress"]
     multi_val_params = ["presWeather", "skyCover", "skyLayerBase"]
     params = single_val_params + multi_val_params
-    station_names, pres_weather, sky_cov, sky_layer_base = [],[],[],[]
+    station_names, pres_weather, sky_cov, sky_layer_base = [], [], [], []
     obs = dict({params: [] for params in params})
     for ob in response:
         avail_params = ob.getParameters()
@@ -77,9 +88,9 @@ def getMetarObs(response):
                     else:
                         obs[param].append(None)
 
-                obs['presWeather'].append(pres_weather);
-                obs['skyCover'].append(sky_cov);
-                obs['skyLayerBase'].append(sky_layer_base);
+                obs['presWeather'].append(pres_weather)
+                obs['skyCover'].append(sky_cov)
+                obs['skyLayerBase'].append(sky_layer_base)
                 pres_weather = []
                 sky_cov = []
                 sky_layer_base = []
@@ -87,6 +98,16 @@ def getMetarObs(response):
 
 
 def getSynopticObs(response):
+    """
+    Processes a DataAccessLayer "sfcobs" response into a dictionary
+    of available parameters.
+
+    Args:
+            response: DAL getGeometry() list
+
+    Returns:
+            A dictionary of synop obs
+    """
     from datetime import datetime
     station_names = []
     params = response[0].getParameters()
@@ -109,9 +130,16 @@ def getSynopticObs(response):
 
 def getForecastRun(cycle, times):
     """
-    :param cycle: Forecast cycle reference time
-    :param times: All available times/cycles
-    :return: DataTime array for a single forecast run
+    Get the latest forecast run (list of objects) from all
+    all cycles and times returned from DataAccessLayer "grid"
+    response.
+
+    Args:
+            cycle: Forecast cycle reference time
+            times: All available times/cycles
+
+    Returns:
+            DataTime array for a single forecast run
     """
     fcstRun = []
     for t in times:
@@ -126,7 +154,7 @@ def getAvailableTimes(request, refTimeOnly=False):
     Args:
             request: the IDataRequest to get data for
             refTimeOnly: optional, use True if only unique refTimes should be
-                          returned (without a forecastHr)
+            returned (without a forecastHr)
 
     Returns:
             a list of DataTimes
@@ -143,7 +171,7 @@ def getGridData(request, times=[]):
     Args:
             request: the IDataRequest to get data for
             times: a list of DataTimes, a TimeRange, or None if the data is time
-                    agnostic
+            agnostic
 
     Returns:
             a list of IGridData
@@ -160,10 +188,10 @@ def getGeometryData(request, times=[]):
     Args:
             request: the IDataRequest to get data for
             times: a list of DataTimes, a TimeRange, or None if the data is time
-                    agnostic
+            agnostic
 
     Returns:
-            a list of IGeometryData
+       a list of IGeometryData
     """
     return router.getGeometryData(request, times)
 
@@ -257,7 +285,7 @@ def getIdentifierValues(request, identifierKey):
     return router.getIdentifierValues(request, identifierKey)
 
 def newDataRequest(datatype=None, **kwargs):
-    """"
+    """
     Creates a new instance of IDataRequest suitable for the runtime environment.
     All args are optional and exist solely for convenience.
 
@@ -267,7 +295,7 @@ def newDataRequest(datatype=None, **kwargs):
             levels: a list of levels to set on the request
             locationNames: a list of locationNames to set on the request
             envelope: an envelope to limit the request
-            **kwargs: any leftover kwargs will be set as identifiers
+            kwargs: any leftover kwargs will be set as identifiers
 
     Returns:
             a new IDataRequest
