@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Pure python logging mechanism for logging to AlertViz from
 # pure python (ie not JEP).  DO NOT USE IN PYTHON CALLED
@@ -17,15 +13,15 @@
 #
 #
 
-import os
 import sys
 
+
 class Record():
     def __init__(self, level=0, msg='Test Message'):
-        self.levelno=level
-        self.message=msg
-        self.exc_info=sys.exc_info()
-        self.exc_text="TEST"
+        self.levelno = level
+        self.message = msg
+        self.exc_info = sys.exc_info()
+        self.exc_text = "TEST"
 
     def getMessage(self):
-        return self.message
\ No newline at end of file
+        return self.message
