@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # __init__.py for awips package
 #
@@ -15,3 +11,4 @@
 #
 #
 
+__all__ = []
