@@ -1,10 +1,7 @@
-##
-##
-
-from __future__ import print_function
 from awips.dataaccess import DataAccessLayer as DAL
 
-import baseBufrMosTestCase
+from awips.test.dafTests import baseBufrMosTestCase
+from awips.test.dafTests import params
 import unittest
 
 #
@@ -17,6 +14,8 @@ import unittest
 #    01/19/16        4795          mapeters       Initial Creation.
 #    04/11/16        5548          tgurney        Cleanup
 #    04/18/16        5548          tgurney        More cleanup
+#    12/07/16        5981          tgurney        Parameterize
+#    12/20/16        5981          tgurney        Inherit all tests
 #
 #
 
@@ -25,11 +24,6 @@ class BufrMosHpcTestCase(baseBufrMosTestCase.BufrMosTestCase):
     """Test DAF support for bufrmosHPC data"""
 
     datatype = "bufrmosHPC"
+    data_params = "forecastHr", "maxTemp24Hour"
 
-    # Most tests inherited from superclass
-
-    def testGetGeometryData(self):
-        req = DAL.newDataRequest(self.datatype)
-        req.setLocationNames("KOMA")
-        req.setParameters("forecastHr", "maxTemp24Hour")
-        self.runGeometryDataTest(req)
+    # All tests inherited from superclass
