@@ -1,8 +1,4 @@
-##
-##
-
 from awips.dataaccess import DataAccessLayer as DAL
-
 from awips.dataaccess import CombinedTimeQuery as CTQ
 
 import unittest
@@ -21,13 +17,14 @@ import os
 #
 #
 
+
 class CombinedTimeQueryTestCase(unittest.TestCase):
 
     @classmethod
     def setUp(cls):
         host = os.environ.get('DAF_TEST_HOST')
         if host is None:
-            host = 'localhost'
+            host = 'edex-cloud.unidata.ucar.edu'
         DAL.changeEDEXHost(host)
 
     def testSuccessfulQuery(self):
