@@ -1,11 +1,10 @@
-##
-##
 #
 #     SOFTWARE HISTORY
 #
 #    Date            Ticket#       Engineer       Description
 #    ------------    ----------    -----------    --------------------------
 #    06/22/2015       4573         randerso       Added svcbu package
+#    10/06/2015                    mjames@ucar    Removed svcbu package
 #
 ##
 
@@ -17,7 +16,6 @@ __all__ = [
             'request',
             'server',
             'slice',
-            'svcbu',
             'weather',
             'GridDataHistory'
           ]
